# Changelog

## v0.0.9 - 2023-03-07

### Fixed
- Fixed an issue with the ChatGPT web.

### Added
- Added support for ChatGPT API and ChatGPT web.
- Support for automatically getting space ID for NotionAI.
- Added a full mode feature.
- Added "append" and "replace" buttons for input boxes in the webpage.
